Constants class
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- cb_config → const String
- errorCode → const String
- errorCodeValue → const int
- errorMsg → const String
- eventType → const String
- name → const String
- onPaymentTerminate → const String
- payUCBFlutter → const String
- payUPaymentParams → const String
- platform → const String
- pluginErrorCode → const int
- post_data → const String
- response → const String
- version → const String